pyprocar.io.abinit.AbinitProcar — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# pyprocar.io.abinit.AbinitProcar

class pyprocar.io.abinit.AbinitProcar(dirname=None, inFiles=None, abinit_output=None, reciprocal_lattice=None, kpath=None, efermi=None)

  This class has functions to parse the PROCAR file generated from Abinit. Unlike, VASP here the PROCAR files need to be merged and fixed for formatting issues prior to further processing.

  Methods

  `AbinitProcar.__init__`([dirname, inFiles, ...]) |